@@ -28,7 +28,7 @@ exchange = None
 container_files_path = None
 
 container_version = "4"
-pypi_version = "0.0.27"
+pypi_version = "0.0.28"
 
 
 def deal_with_stdout():
@@ -52,7 +52,9 @@ def import_all_c2_functions():
     try:
         for x in modules:
             if not x.endswith("__init__.py") and x[-3:] == ".py":
-                module = import_module("c2_functions." + pathlib.Path(x).stem, package=None)
+                module = import_module(
+                    "c2_functions." + pathlib.Path(x).stem, package=None
+                )
                 for el in dir(module):
                     if "__" not in el:
                         globals()[el] = getattr(module, el)
@@ -93,7 +95,10 @@ async def callback(message: aio_pika.IncomingMessage):
                     await send_status(
                         message=json.dumps(c2profile),
                         routing_key="c2.status.{}.{}.sync_classes.{}.{}".format(
-                            hostname, "running" if running else "stopped", username, container_version
+                            hostname,
+                            "running" if running else "stopped",
+                            username,
+                            container_version,
                         ),
                     )
                 except Exception as e:
@@ -102,16 +107,25 @@ async def callback(message: aio_pika.IncomingMessage):
                             str(traceback.format_exc())
                         ),
                         routing_key="c2.status.{}.{}.sync_classes.{}.{}".format(
-                            hostname, "running" if running else "stopped", username, container_version
+                            hostname,
+                            "running" if running else "stopped",
+                            username,
+                            container_version,
                         ),
                     )
             else:
                 print("Unknown command: {}".format(command))
                 sys.stdout.flush()
         except Exception as e:
-            print("[-] Failed overall message processing: " +  str(sys.exc_info()[-1].tb_lineno) + " " +str(e))
+            print(
+                "[-] Failed overall message processing: "
+                + str(sys.exc_info()[-1].tb_lineno)
+                + " "
+                + str(e)
+            )
             sys.stdout.flush()
 
+
 async def get_status(request):
     global running
     global process
@@ -129,7 +143,7 @@ async def get_status(request):
         "running": running,
         "output": output,
         "status": "success",
-        "version": container_version
+        "version": container_version,
     }
     output = ""
     return output_message
@@ -146,17 +160,19 @@ async def start_profile(request):
         server_options = glob.glob(str(server_option_path))
         print(server_options)
         if len(server_options) == 0:
-            print_flush(f"[-] no files that start with '{server_option_path}' in the name in the c2_code directory")
+            print_flush(
+                f"[-] no files that start with '{server_option_path}' in the name in the c2_code directory"
+            )
             running = False
             output_message = {
                 "status": "error",
                 "running": False,
-                "error": "Failed to find server file"
+                "error": "Failed to find server file",
             }
             return output_message
         else:
             server_path = server_options[0]
-        #server_path = container_files_path / "server"
+        # server_path = container_files_path / "server"
         print(f"[*] c2 server path: {server_path}")
         output_message = {}
         if not running:
@@ -167,7 +183,7 @@ async def start_profile(request):
                 stdout=subprocess.PIPE,
                 stderr=subprocess.STDOUT,
                 cwd=str(container_files_path),
-                shell=True
+                shell=True,
             )
             thread = _thread.start_new_thread(deal_with_stdout, ())
             time.sleep(3)
@@ -179,8 +195,7 @@ async def start_profile(request):
                     "status": "success",
                     "running": running,
                     "output": "Failed to start\nOutput: {}".format(output),
-                    "version": container_version
-
+                    "version": container_version,
                 }
                 output = ""
             else:
@@ -188,9 +203,10 @@ async def start_profile(request):
                 output_message = {
                     "status": "success",
                     "running": running,
-                    "output": "Started with pid: {}...\nOutput: {}".format(str(process.pid), output),
-                    "version": container_version
-
+                    "output": "Started with pid: {}...\nOutput: {}".format(
+                        str(process.pid), output
+                    ),
+                    "version": container_version,
                 }
                 output = ""
         else:
@@ -198,14 +214,18 @@ async def start_profile(request):
                 "status": "success",
                 "running": running,
                 "output": "Already running...\nOutput: {}".format(output),
-                "version": container_version
+                "version": container_version,
             }
             output = ""
         return output_message
     except Exception as e:
         print_flush(
-                "Exception trying to send message back to container for start_profile! " + str(sys.exc_info()[-1].tb_lineno) + " " + str(e)
-            )
+            "Exception trying to send message back to container for start_profile! "
+            + str(sys.exc_info()[-1].tb_lineno)
+            + " "
+            + str(e)
+        )
+
 
 async def stop_profile(request):
     global running
@@ -216,19 +236,19 @@ async def stop_profile(request):
     try:
         if running:
             try:
-                #print("trying to kill")
+                # print("trying to kill")
                 process.kill()
-                #print("killed, trying to communicate")
+                # print("killed, trying to communicate")
                 process.communicate(timeout=3)
-                #print("communicated")
+                # print("communicated")
             except Exception as e:
                 print(f"[-] hit exception during subprocess kill: {e}")
                 sys.stdout.flush()
                 pass
             try:
-                #print("trying to exit thread")
+                # print("trying to exit thread")
                 thread.exit()
-                #print("exited thread")
+                # print("exited thread")
             except Exception as e:
                 print(f"[-] hit exception killing thread listening for output: {e}")
                 sys.stdout.flush()
@@ -238,7 +258,7 @@ async def stop_profile(request):
                 "status": "success",
                 "output": "Process killed...\nOld Output: {}".format(output),
                 "running": running,
-                "version": container_version
+                "version": container_version,
             }
             output = ""
         else:
@@ -246,14 +266,17 @@ async def stop_profile(request):
                 "status": "success",
                 "running": running,
                 "output": "Process not running...\nOld Output: {}".format(output),
-                "version": container_version
+                "version": container_version,
             }
             output = ""
         return output_message
     except Exception as e:
         print_flush(
-                "[-] Exception trying to send message back to container for stop_profile! " + str(sys.exc_info()[-1].tb_lineno) + " " + str(e)
-            )
+            "[-] Exception trying to send message back to container for stop_profile! "
+            + str(sys.exc_info()[-1].tb_lineno)
+            + " "
+            + str(e)
+        )
 
 
 async def sync_classes():
@@ -272,8 +295,11 @@ async def sync_classes():
         )
     except Exception as e:
         print_flush(
-                "[-] Exception trying to send message back to container for sync_classes! " + str(sys.exc_info()[-1].tb_lineno) + " " + str(e)
-            )
+            "[-] Exception trying to send message back to container for sync_classes! "
+            + str(sys.exc_info()[-1].tb_lineno)
+            + " "
+            + str(e)
+        )
         await send_status(
             message='{"message": "Error while syncing info: {}"}'.format(
                 str(traceback.format_exc())
@@ -292,12 +318,12 @@ async def get_file(request):
         file_data = open(path, "rb").read()
     except Exception as e:
         file_data = b"File not found"
-    return{
+    return {
         "status": "success",
         "running": running,
         "filename": str(path),
         "data": base64.b64encode(file_data).decode("utf-8"),
-        "version": container_version
+        "version": container_version,
     }
 
 
@@ -317,7 +343,7 @@ async def write_file(request):
                 "status": "error",
                 "error": "trying to break out of path",
                 "running": running,
-                "version": container_version
+                "version": container_version,
             }
         else:
             file = open(file_path, "wb")
@@ -327,14 +353,14 @@ async def write_file(request):
                 "status": "success",
                 "filename": str(file_path),
                 "running": running,
-                "version": container_version
+                "version": container_version,
             }
     except Exception as e:
         response = {
             "status": "error",
             "error": str(e),
             "running": running,
-            "version": container_version
+            "version": container_version,
         }
     return response
 
@@ -359,15 +385,22 @@ async def rabbit_c2_rpc_callback(
                 ).encode()
             try:
                 await exchange.publish(
-                    aio_pika.Message(body=response, correlation_id=message.correlation_id),
+                    aio_pika.Message(
+                        body=response, correlation_id=message.correlation_id
+                    ),
                     routing_key=message.reply_to,
                 )
             except Exception as e:
                 print_flush(
-                    "[-] Exception trying to send message back to container for rpc! " + str(sys.exc_info()[-1].tb_lineno) + " " + str(e)
+                    "[-] Exception trying to send message back to container for rpc! "
+                    + str(sys.exc_info()[-1].tb_lineno)
+                    + " "
+                    + str(e)
                 )
     except Exception as d:
-        print_flush(f"[-] Failed to process message in rabbit_c2_rpc_callback: {str(sys.exc_info()[-1].tb_lineno)} {str(d)} ")
+        print_flush(
+            f"[-] Failed to process message in rabbit_c2_rpc_callback: {str(sys.exc_info()[-1].tb_lineno)} {str(d)} "
+        )
 
 
 async def connect_and_consume_rpc(debug):
@@ -376,38 +409,60 @@ async def connect_and_consume_rpc(debug):
     while connection is None:
         try:
             if debug:
-                print_flush(f"[*] C2RPCTasking Step 1/3: Connecting to rabbitmq in connect_and_consume_rpc with c2 {hostname}")
+                print_flush(
+                    f"[*] C2RPCTasking Step 1/3: Connecting to rabbitmq in connect_and_consume_rpc with c2 {hostname}"
+                )
             connection = await aio_pika.connect_robust(
                 host=settings.get("host", "127.0.0.1"),
                 login=settings.get("username", "mythic_user"),
                 password=settings.get("password", "mythic_password"),
-                virtualhost=settings.get("virtual_host", "mythic_vhost"),
+                virtualhost="mythic_vhost",
             )
             if debug:
-                print_flush(f"[+] C2RPCTasking Step 1/3 Done: Successfully connected in connect_and_consume_rpc with c2 {hostname}")
+                print_flush(
+                    f"[+] C2RPCTasking Step 1/3 Done: Successfully connected in connect_and_consume_rpc with c2 {hostname}"
+                )
         except (ConnectionError, ConnectionRefusedError) as c:
-            print_flush("[-] C2RPCTasking Step 1/3 Error: Connection to rabbitmq failed, trying again...")
+            print_flush(
+                "[-] C2RPCTasking Step 1/3 Error: Connection to rabbitmq failed, trying again..."
+            )
         except Exception as e:
-            print_flush("[-] C2RPCTasking Step 1/3 Error: Exception in connect_and_consume_rpc connect: {}\n trying again...".format(str(e)))
+            print_flush(
+                "[-] C2RPCTasking Step 1/3 Error: Exception in connect_and_consume_rpc connect: {}\n trying again...".format(
+                    str(e)
+                )
+            )
         await asyncio.sleep(5)
     channel = await connection.channel()
     # get a random queue that only the apfell server will use to listen on to catch all heartbeats
     if debug:
-        print_flush("[*] C2RPCTasking Step 2/3: Declaring container specific rpc queue in connect_and_consume_rpc")
-    queue = await channel.declare_queue("{}_rpc_queue".format(hostname), auto_delete=True)
+        print_flush(
+            "[*] C2RPCTasking Step 2/3: Declaring container specific rpc queue in connect_and_consume_rpc"
+        )
+    queue = await channel.declare_queue(
+        "{}_rpc_queue".format(hostname), auto_delete=True
+    )
     if debug:
-            print_flush(f"[+] C2RPCTasking Step 2/3 Done: Successfully declared container specific rpc queue in connect_and_consume_rpc with c2 {hostname}")
+        print_flush(
+            f"[+] C2RPCTasking Step 2/3 Done: Successfully declared container specific rpc queue in connect_and_consume_rpc with c2 {hostname}"
+        )
     await channel.set_qos(prefetch_count=10)
     try:
         if debug:
-            print_flush(f"[*] C2RPCTasking Step 3/3: Starting to consume callbacks in connect_and_consume_rpc with c2 {hostname}")
+            print_flush(
+                f"[*] C2RPCTasking Step 3/3: Starting to consume callbacks in connect_and_consume_rpc with c2 {hostname}"
+            )
         if debug:
-            print_flush("[*] MythicService Step 4/5 Done: Created task for connect_and_consume_rpc from mythic_service")
-        await queue.consume(
-            partial(rabbit_c2_rpc_callback, channel.default_exchange)
-        )
+            print_flush(
+                "[*] MythicService Step 4/5 Done: Created task for connect_and_consume_rpc from mythic_service"
+            )
+        await queue.consume(partial(rabbit_c2_rpc_callback, channel.default_exchange))
     except Exception as e:
-        print_flush("[-] C2RPCTasking Step 3/3 Error: Exception in connect_and_consume_rpc .consume: {}".format(str(sys.exc_info()[-1].tb_lineno) + " " + str(e)))
+        print_flush(
+            "[-] C2RPCTasking Step 3/3 Error: Exception in connect_and_consume_rpc .consume: {}".format(
+                str(sys.exc_info()[-1].tb_lineno) + " " + str(e)
+            )
+        )
 
 
 async def rabbit_mythic_c2_rpc_callback(
@@ -418,16 +473,24 @@ async def rabbit_mythic_c2_rpc_callback(
             request = json.loads(message.body.decode())
             response = await globals()[request["action"]](request)
         except Exception as e:
-            print_flush(f"[-] Failed to process message in rabbit_mythic_c2_rpc_callback")
+            print_flush(
+                f"[-] Failed to process message in rabbit_mythic_c2_rpc_callback"
+            )
             response = {"status": "error", "error": str(e)}
         try:
             await exchange.publish(
-                aio_pika.Message(body=json.dumps(response).encode(), correlation_id=message.correlation_id),
+                aio_pika.Message(
+                    body=json.dumps(response).encode(),
+                    correlation_id=message.correlation_id,
+                ),
                 routing_key=message.reply_to,
             )
         except Exception as e:
             print_flush(
-                "[-] Exception trying to send message back to container for rpc! " + str(sys.exc_info()[-1].tb_lineno) + " " + str(e)
+                "[-] Exception trying to send message back to container for rpc! "
+                + str(sys.exc_info()[-1].tb_lineno)
+                + " "
+                + str(e)
             )
 
 
@@ -437,42 +500,68 @@ async def connect_and_consume_mythic_rpc(debug):
     while connection is None:
         try:
             if debug:
-                print_flush(f"[*] MythicRPCTasking Step 1/3: Connecting to rabbitmq in connect_and_consume_mythic_rpc with c2 {hostname}")
+                print_flush(
+                    f"[*] MythicRPCTasking Step 1/3: Connecting to rabbitmq in connect_and_consume_mythic_rpc with c2 {hostname}"
+                )
             connection = await aio_pika.connect_robust(
                 host=settings.get("host", "127.0.0.1"),
                 login=settings.get("username", "mythic_user"),
                 password=settings.get("password", "mythic_password"),
-                virtualhost=settings.get("virtual_host", "mythic_vhost"),
+                virtualhost="mythic_vhost",
             )
             if debug:
-                print_flush(f"[+] MythicRPCTasking Step 1/3 Done: Successfully connected in connect_and_consume_mythic_rpc with c2 {hostname}")
+                print_flush(
+                    f"[+] MythicRPCTasking Step 1/3 Done: Successfully connected in connect_and_consume_mythic_rpc with c2 {hostname}"
+                )
         except (ConnectionError, ConnectionRefusedError) as c:
-            print_flush("[-] MythicRPCTasking Step 1/3 Error: Connection to rabbitmq failed, trying again...")
+            print_flush(
+                "[-] MythicRPCTasking Step 1/3 Error: Connection to rabbitmq failed, trying again..."
+            )
         except Exception as e:
-            print_flush("[-] MythicRPCTasking Step 1/3 Error: Exception in connect_and_consume_mythic_rpc connect: {}\n trying again...".format(str(e)))
+            print_flush(
+                "[-] MythicRPCTasking Step 1/3 Error: Exception in connect_and_consume_mythic_rpc connect: {}\n trying again...".format(
+                    str(e)
+                )
+            )
         await asyncio.sleep(5)
     channel = await connection.channel()
     # get a random queue that only the apfell server will use to listen on to catch all heartbeats
     if debug:
-        print_flush(f"[*] MythicRPCTasking Step 2/3: Declaring container specific mythic rpc queue in connect_and_consume_mythic_rpc with c2 {hostname}")
-    queue = await channel.declare_queue("{}_mythic_rpc_queue".format(hostname), auto_delete=True)
+        print_flush(
+            f"[*] MythicRPCTasking Step 2/3: Declaring container specific mythic rpc queue in connect_and_consume_mythic_rpc with c2 {hostname}"
+        )
+    queue = await channel.declare_queue(
+        "{}_mythic_rpc_queue".format(hostname), auto_delete=True
+    )
     await channel.set_qos(prefetch_count=10)
     if debug:
-        print_flush(f"[+] MythicRPCTasking Step 2/3 Done: Declared container specific mythic rpc queue in connect_and_consume_mythic_rpc with c2 {hostname}")
+        print_flush(
+            f"[+] MythicRPCTasking Step 2/3 Done: Declared container specific mythic rpc queue in connect_and_consume_mythic_rpc with c2 {hostname}"
+        )
     try:
         if debug:
-            print_flush(f"[*] MythicRPCTasking Step 3/3: Starting to consume callbacks in connect_and_consume_mythic_rpc with c2 {hostname}")
+            print_flush(
+                f"[*] MythicRPCTasking Step 3/3: Starting to consume callbacks in connect_and_consume_mythic_rpc with c2 {hostname}"
+            )
         task = await queue.consume(
             partial(rabbit_mythic_c2_rpc_callback, channel.default_exchange)
         )
         if debug:
-            print_flush(f"[+] MythicRPCTasking Step 3/3 Done: Started to consume callbacks in connect_and_consume_mythic_rpc with c2 {hostname}")
+            print_flush(
+                f"[+] MythicRPCTasking Step 3/3 Done: Started to consume callbacks in connect_and_consume_mythic_rpc with c2 {hostname}"
+            )
         if debug:
-            print_flush("[*] MythicService Step 5/5 Done: Created task for connect_and_consume_mythic_rpc from mythic_service")
+            print_flush(
+                "[*] MythicService Step 5/5 Done: Created task for connect_and_consume_mythic_rpc from mythic_service"
+            )
         # wait to sync classes with mythic until we have a way to get messages back
         await sync_classes()
     except Exception as e:
-        print_flush("[-] MythicRPCTasking Step 3/3 Error: Exception in connect_and_consume_mythic_rpc .consume: {}".format(str(sys.exc_info()[-1].tb_lineno) + " " + str(e)))
+        print_flush(
+            "[-] MythicRPCTasking Step 3/3 Error: Exception in connect_and_consume_mythic_rpc .consume: {}".format(
+                str(sys.exc_info()[-1].tb_lineno) + " " + str(e)
+            )
+        )
 
 
 async def mythic_service(debug: bool):
@@ -480,44 +569,59 @@ async def mythic_service(debug: bool):
     global exchange
     global container_files_path
     connection = None
-    hostname = settings.get("name", "hostname")
-    
-    if hostname == "hostname":
-        hostname = socket.gethostname()
-    if debug:
-        print_flush(f"[*] MythicService: Setting c2 name to {hostname}")
     container_files_path = pathlib.Path(
-        os.path.abspath(settings.get("container_files_path", "/Mythic/"))
-    )
+        os.path.abspath(os.path.dirname(__file__))
+    ).parent
+    print_flush(f"[*] Importing C2 Profile information")
+    import_all_c2_functions()
+    for cls in C2ProfileBase.C2Profile.__subclasses__():
+        hostname = cls().name
+        break
+    print_flush(f"[*] MythicService: Setting c2 name to {hostname}")
     if debug:
-        print_flush(f"[*] MythicService: Setting the absolute path to the c2's folder as: {container_files_path}")
+        print_flush(
+            f"[*] MythicService: Setting the absolute path to the c2's folder as: {container_files_path}"
+        )
     container_files_path = container_files_path / "c2_code"
     while connection is None:
         try:
             if debug:
-                print_flush("[*] MythicService Step 1/5: Connecting to rabbitmq from mythic_service")
+                print_flush(
+                    "[*] MythicService Step 1/5: Connecting to rabbitmq from mythic_service"
+                )
             connection = await aio_pika.connect_robust(
                 host=settings.get("host", "127.0.0.1"),
                 login=settings.get("username", "mythic_user"),
                 password=settings.get("password", "mythic_password"),
-                virtualhost=settings.get("virtual_host", "mythic_vhost"),
+                virtualhost="mythic_vhost",
             )
             if debug:
-                print_flush("[+] MythicService Step 1/5 Done: Successfully connected to rabbitmq from mythic_service")
+                print_flush(
+                    "[+] MythicService Step 1/5 Done: Successfully connected to rabbitmq from mythic_service"
+                )
         except (ConnectionError, ConnectionRefusedError) as c:
-            print_flush("[-] MythicService Step 1/5 Error: Connection to rabbitmq failed, trying again...")
+            print_flush(
+                "[-] MythicService Step 1/5 Error: Connection to rabbitmq failed, trying again..."
+            )
         except Exception as e:
-            print_flush("[-] MythicService Step 1/5 Error: Exception in mythic_service: " + str(traceback.format_exc()))
+            print_flush(
+                "[-] MythicService Step 1/5 Error: Exception in mythic_service: "
+                + str(traceback.format_exc())
+            )
         await asyncio.sleep(5)
     try:
         channel = await connection.channel()
         if debug:
-            print_flush("[*] MythicService Step 2/5: Declaring exchange in mythic_service")
+            print_flush(
+                "[*] MythicService Step 2/5: Declaring exchange in mythic_service"
+            )
         exchange = await channel.declare_exchange(
             "mythic_traffic", aio_pika.ExchangeType.TOPIC
         )
         if debug:
-            print_flush("[+] MythicService Step 2/5 Done: Successfully declared queue in mythic_service")
+            print_flush(
+                "[+] MythicService Step 2/5 Done: Successfully declared queue in mythic_service"
+            )
         queue = await channel.declare_queue("", exclusive=True)
         await queue.bind(
             exchange="mythic_traffic", routing_key="c2.modify.{}.#".format(hostname)
@@ -525,59 +629,91 @@ async def mythic_service(debug: bool):
         # just want to handle one message at a time so we can clean up and be ready
         await channel.set_qos(prefetch_count=30)
         if debug:
-            print_flush("[*] MythicService Step 3/5: Creating task to consume in mythic_service")
+            print_flush(
+                "[*] MythicService Step 3/5: Creating task to consume in mythic_service"
+            )
         task = queue.consume(callback)
         if debug:
-            print_flush("[+] MythicService Step 3/5 Done: Successfully created task to consume in mythic_service")
+            print_flush(
+                "[+] MythicService Step 3/5 Done: Successfully created task to consume in mythic_service"
+            )
         if debug:
-            print_flush("[*] MythicService Step 4/5: Creating task for connect_and_consume_rpc from mythic_service")
+            print_flush(
+                "[*] MythicService Step 4/5: Creating task for connect_and_consume_rpc from mythic_service"
+            )
         task4 = asyncio.ensure_future(connect_and_consume_rpc(debug))
-        
+
         if debug:
-            print_flush("[*] MythicService Step 5/5: Creating task for connect_and_consume_mythic_rpc from mythic_service")
+            print_flush(
+                "[*] MythicService Step 5/5: Creating task for connect_and_consume_mythic_rpc from mythic_service"
+            )
         task5 = asyncio.ensure_future(connect_and_consume_mythic_rpc(debug))
         if debug:
-            print_flush("[*] MythicService Step 5/5: Created task for connect_and_consume_mythic_rpc from mythic_service")
-        print("[+] MythicService Listening for RabbitMQ Tasks from Mythic".format(hostname))
+            print_flush(
+                "[*] MythicService Step 5/5: Created task for connect_and_consume_mythic_rpc from mythic_service"
+            )
+        print(
+            "[+] MythicService Listening for RabbitMQ Tasks from Mythic".format(
+                hostname
+            )
+        )
         if debug:
-            print_flush("[*] MythicService Waiting for all tasks to finish in mythic_service")
+            print_flush(
+                "[*] MythicService Waiting for all tasks to finish in mythic_service"
+            )
         result = await asyncio.gather(task, task4, task5)
     except Exception as e:
-        print_flush("[-] MythicService Exception in mythic_service: " + str(traceback.format_exc()))
-    
+        print_flush(
+            "[-] MythicService Exception in mythic_service: "
+            + str(traceback.format_exc())
+        )
 
 
 async def heartbeat_loop(debug: bool):
     connection = None
-    hostname = settings.get("name", "hostname")
-    if hostname == "hostname":
-        hostname = socket.gethostname()
+    import_all_c2_functions()
+    for cls in C2ProfileBase.C2Profile.__subclasses__():
+        hostname = cls().name
+        break
     while connection is None:
         try:
             if debug:
-                print_flush("[*] Heartbeats Step 1/2: Connecting to rabbitmq from heartbeat_loop")
+                print_flush(
+                    "[*] Heartbeats Step 1/2: Connecting to rabbitmq from heartbeat_loop"
+                )
             connection = await aio_pika.connect_robust(
                 host=settings.get("host", "127.0.0.1"),
                 login=settings.get("username", "mythic_user"),
                 password=settings.get("password", "mythic_password"),
-                virtualhost=settings.get("virtual_host", "mythic_vhost"),
+                virtualhost="mythic_vhost",
             )
             if debug:
-                print_flush("[+] Heartbeats Step 1/2 Done: Successfully connected to rabbitmq from heartbeat_loop")
+                print_flush(
+                    "[+] Heartbeats Step 1/2 Done: Successfully connected to rabbitmq from heartbeat_loop"
+                )
             channel = await connection.channel()
             if debug:
-                print_flush("[*] Heartbeats Step 2/2: Declaring exchange in heartbeat_loop for channel")
+                print_flush(
+                    "[*] Heartbeats Step 2/2: Declaring exchange in heartbeat_loop for channel"
+                )
             exchange = await channel.declare_exchange(
                 "mythic_traffic", aio_pika.ExchangeType.TOPIC
             )
             if debug:
-                print_flush("[+] Heartbeats Step 2/2 Done: Declared exchange in heartbeat_loop for channel")
+                print_flush(
+                    "[+] Heartbeats Step 2/2 Done: Declared exchange in heartbeat_loop for channel"
+                )
         except (ConnectionError, ConnectionRefusedError) as c:
-            print_flush("[-] Heartbeats Step 2/2 Error: Connection to rabbitmq failed, trying again...")
+            print_flush(
+                "[-] Heartbeats Step 2/2 Error: Connection to rabbitmq failed, trying again..."
+            )
             await asyncio.sleep(5)
             continue
         except Exception as e:
-            print_flush("[-] Heartbeats Step 2/2 Error: Exception in heartbeat_loop: " + str(traceback.format_exc()))
+            print_flush(
+                "[-] Heartbeats Step 2/2 Error: Exception in heartbeat_loop: "
+                + str(traceback.format_exc())
+            )
             await asyncio.sleep(5)
             continue
         while True:
@@ -591,10 +727,16 @@ async def heartbeat_loop(debug: bool):
                 )
                 await asyncio.sleep(10)
             except Exception as e:
-                print_flush("[-] Heartbeats Exception in heartbeat_loop trying to send heartbeat: " + str(sys.exc_info()[-1].tb_lineno) + " " + str(e))
+                print_flush(
+                    "[-] Heartbeats Exception in heartbeat_loop trying to send heartbeat: "
+                    + str(sys.exc_info()[-1].tb_lineno)
+                    + " "
+                    + str(e)
+                )
                 # if we get an exception here, break out to the bigger loop and try to connect again
                 break
 
+
 # start our service
 def start_service_and_heartbeat(debug=False):
     loop = asyncio.get_event_loop()
@@ -602,6 +744,7 @@ def start_service_and_heartbeat(debug=False):
     asyncio.gather(mythic_service(debug), heartbeat_loop(debug))
     loop.run_forever()
 
+
 def get_version_info():
     print_flush("[*] Mythic C2 Profile Version: " + container_version)
     print_flush("[*] Mythic C2 Profile PyPi Version: " + pypi_version)
